--[[
AdiFocusBar - Smart focus bar for hunters.
Copyright 2010-2013 Adirelle (adirelle@gmail.com)
All rights reserved.
--]]

if select(2, UnitClass("player")) ~= "HUNTER" then return end
local addonName, ns = ...
local addon, Debug = ns.addon, ns.Debug

------------------------------------------------------------------------------
-- Configuration
------------------------------------------------------------------------------

local options
local function GetOptions()
	if not options then
		options = {
			name = addonName,
			type = 'group',
			set = function(info, value)
				addon.db.profile[info[#info]] = value
				addon:TestVisibility('config')
			end,
			get = function(info)
				return addon.db.profile[info[#info]]
			end,
			args = {
				barThreshold = {
					name = 'Show focus bar ...',
					order = 10,
					type = 'select',
					values = { "Always", "In any combat", "Against elite mobs", "Against bosses", "Never" }
				},
				forecastThreshold = {
					name = 'Show spell forecast ...',
					order = 20,
					type = 'select',
					values = { nil, "In any combat", "Against elite mobs", "Against bosses", "Never" }
				},
				dpsCooldownThreshold = {
					name = 'Suggest DPS cooldowns ...',
					order = 30,
					type = 'select',
					values = { nil, "In any combat", "Against elite mobs", "Against bosses", "Never" }
				},
				marks = {
					name = 'Show spell marks',
					order = 40,
					type = 'toggle',
					disabled = function() return addon.db.profile.barThreshold == 5 end,
				},
				layout = {
					name = 'Layout',
					order = 45,
					type = 'group',
					inline = true,
					args = {
						locked = {
							name = function()
								return addon:AreMovablesLocked() and "Unlock" or "Lock"
							end,
							order = 10,
							type = 'execute',
							func = function()
								if addon:AreMovablesLocked() then
									addon:UnlockMovables()
								else
									addon:LockMovables()
								end
							end
						},
						reset = {
							name = 'Reset',
							order = 20,
							type = 'execute',
							func = function() addon:ResetMovableLayout() end
						}
					}
				},
			},
		}
	end
	return options
end

------------------------------------------------------------------------------
-- Setup
------------------------------------------------------------------------------

function addon:SetupConfig()
	-- Create the config panel
	LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, GetOptions)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName, addonName)

	-- Add a macro command to open it
	SlashCmdList["ADIFOCUSBAR"] = function()
		InterfaceOptionsFrame_OpenToCategory(addonName)
	end
	SLASH_ADIFOCUSBAR1 = "/adifocusbar"
	SLASH_ADIFOCUSBAR2 = "/afb"
end
